@@ -1,41 +1,17 @@
-# Copyright (C) 1998-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.bounce
-#
-# flufl.bounce is free software: you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as published by the
-# Free Software Foundation, version 3 of the License.
-#
-# flufl.bounce is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.bounce.  If not, see <http://www.gnu.org/licenses/>.
-
 """Parse RFC 3464 (i.e. DSN) bounce formats.
 
 RFC 3464 obsoletes 1894 which was the old DSN standard.  This module has not
 been audited for differences between the two.
 """
 
-from __future__ import absolute_import, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'DSN',
-    ]
-
-
 from email.iterators import typed_subpart_iterator
 from email.utils import parseaddr
+from flufl.bounce.interfaces import IBounceDetector
+from public import public
 from zope.interface import implementer
 
-from flufl.bounce.interfaces import IBounceDetector
 
-
-
+@public
 @implementer(IBounceDetector)
 class DSN:
     """Parse RFC 3464 (i.e. DSN) bounce formats."""
@@ -94,11 +70,11 @@ class DSN:
         # requires byte addresses.
         return (
             # First, the delayed, or temporary failures.
-            set(parseaddr(address)[1].encode('us-ascii') 
+            set(parseaddr(address)[1].encode('us-ascii')
                 for address in delayed_addresses
                 if address is not None),
             # And now the failed or permanent failures.
-            set(parseaddr(address)[1].encode('us-ascii') 
+            set(parseaddr(address)[1].encode('us-ascii')
                 for address in failed_addresses
                 if address is not None)
             )
