@@ -1,19 +1,3 @@
-# Copyright (C) 1998-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.bounce
-#
-# flufl.bounce is free software: you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as published by the
-# Free Software Foundation, version 3 of the License.
-#
-# flufl.bounce is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.bounce.  If not, see <http://www.gnu.org/licenses/>.
-
 """This appears to be the format for Novell GroupWise and NTMail
 
 X-Mailer: Novell GroupWise Internet Agent 5.5.3.1
@@ -21,28 +5,19 @@ X-Mailer: NTMail v4.30.0012
 X-Mailer: Internet Mail Service (5.5.2653.19)
 """
 
-from __future__ import absolute_import, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'GroupWise',
-    ]
-
-
 import re
 
 from email.message import Message
-from io import BytesIO
-from zope.interface import implementer
-
 from flufl.bounce.interfaces import (
     IBounceDetector, NoFailures, NoTemporaryFailures)
+from io import BytesIO
+from public import public
+from zope.interface import implementer
 
 
 acre = re.compile(b'<(?P<addr>[^>]*)>')
 
 
-
 def find_textplain(msg):
     if msg.get_content_type() == 'text/plain':
         return msg
@@ -56,7 +31,7 @@ def find_textplain(msg):
     return None
 
 
-
+@public
 @implementer(IBounceDetector)
 class GroupWise:
     """Parse Novell GroupWise and NTMail bounces."""
@@ -65,6 +40,8 @@ class GroupWise:
         """See `IBounceDetector`."""
         if msg.get_content_type() != 'multipart/mixed' or not msg['x-mailer']:
             return NoFailures
+        if msg['x-mailer'][:3].lower() not in ('nov', 'ntm', 'int'):
+            return NoFailures
         addresses = set()
         # Find the first text/plain part in the message.
         text_plain = find_textplain(msg)
